      #include <R.h>
      
      void F77_SUB(rndstart)(void) { GetRNGstate(); }
      void F77_SUB(rndend)(void) { PutRNGstate(); }
      float F77_SUB(unifrnd)(void) { return unif_rand(); }
